@@ -38,6 +38,7 @@
 #undef ENABLE_MEM_PROFILE
 
 #undef G_COMPILED_WITH_DEBUGGING
+#undef G_THREADS_ENABLED
 #undef HAVE_BROKEN_WCTYPE
 #undef HAVE_DOPRNT
 #undef HAVE_FLOAT_H
@@ -84,6 +85,8 @@
 #undef WIN32
 #undef NATIVE_WIN32
 
+#undef G_THREAD_SOURCE
+
 /* #undef PACKAGE */
 /* #undef VERSION */
 
