@@ -16,6 +16,11 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+
+/* 
+ * MT safe
+ */
+
 #include "glib.h"
 
 #include <time.h>
@@ -383,6 +388,8 @@ g_date_clear (GDate       *d, guint ndates)
   memset (d, 0x0, ndates*sizeof (GDate)); 
 }
 
+G_LOCK_DECLARE_STATIC (g_date_global);
+
 /* These are for the parser, output to the user should use *
  * g_date_strftime () - this creates more never-freed memory to annoy
  * all those memory debugger users. :-) 
@@ -429,6 +436,7 @@ typedef struct _GDateParseTokens GDateParseTokens;
 
 #define NUM_LEN 10
 
+/* HOLDS: g_date_global_lock */
 static void
 g_date_fill_parse_tokens (const gchar *str, GDateParseTokens *pt)
 {
@@ -488,7 +496,7 @@ g_date_fill_parse_tokens (const gchar *str, GDateParseTokens *pt)
               if (found != NULL)
                 {
                   pt->month = i;
-                  return;
+		  return;
                 }
             }
 	  
@@ -502,12 +510,13 @@ g_date_fill_parse_tokens (const gchar *str, GDateParseTokens *pt)
                   return;
                 }
             }
-	  
+
           ++i;
-        }
+        }      
     }
 }
 
+/* HOLDS: g_date_global_lock */
 static void
 g_date_prepare_to_parse (const gchar *str, GDateParseTokens *pt)
 {
@@ -557,7 +566,9 @@ g_date_prepare_to_parse (const gchar *str, GDateParseTokens *pt)
       
       /* Determine DMY order */
       
-      g_date_set_dmy (&d, 4, 7, 1776); /* had to pick a random day */
+      /* had to pick a random day - don't change this, some strftimes
+       * are broken on some days, and this one is good so far. */
+      g_date_set_dmy (&d, 4, 7, 1976);
       
       g_date_strftime (buf, 127, "%x", &d);
       
@@ -576,7 +587,7 @@ g_date_prepare_to_parse (const gchar *str, GDateParseTokens *pt)
               break;
             case 76:
               using_twodigit_years = TRUE; /* FALL THRU */
-            case 1776:
+            case 1976:
               dmy_order[i] = G_DATE_YEAR;
               break;
             default:
@@ -641,6 +652,8 @@ g_date_set_parse (GDate       *d,
   /* set invalid */
   g_date_clear (d, 1);
   
+  G_LOCK (g_date_global);
+
   g_date_prepare_to_parse (str, &pt);
   
 #ifdef G_ENABLE_DEBUG
@@ -649,7 +662,11 @@ g_date_set_parse (GDate       *d,
 #endif
   
   
-  if (pt.num_ints == 4) return; /* presumably a typo; bail out. */
+  if (pt.num_ints == 4) 
+    {
+      G_UNLOCK (g_date_global);
+      return; /* presumably a typo; bail out. */
+    }
   
   if (pt.num_ints > 1)
     {
@@ -765,6 +782,7 @@ g_date_set_parse (GDate       *d,
   else 
     g_message ("Rejected DMY %u %u %u", day, m, y);
 #endif
+  G_UNLOCK (g_date_global);
 }
 
 void         
